==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/dlight.nativeexecution/src/org/netbeans/modules/nativeexecution/support/ui/SSHKeyFileCompletionProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */
package org.netbeans.modules.nativeexecution.support.ui;

import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
import org.netbeans.modules.nativeexecution.support.ui.api.FileNamesCompletionProvider;
import org.openide.util.Utilities;

/**
 * Doesn't work on Windows
 * 
 * @author akrasny
 */
public final class SSHKeyFileCompletionProvider extends FileNamesCompletionProvider {

    final boolean isWindows = Utilities.isWindows();

    public SSHKeyFileCompletionProvider() {
        super(ExecutionEnvironmentFactory.getLocal());
    }

    @Override
    protected List<String> listDir(String dir) {
        if (isWindows) {
            return Collections.emptyList();
        }

        File dirFile = new File(dir);

        if (!dirFile.exists() || !dirFile.isDirectory()) {
            return Collections.emptyList();
        }

        final File[] listFiles = dirFile.listFiles(SSHKeyFileFilter.getInstance());

        if (listFiles == null) {
            return Collections.emptyList();
        }

        List<String> result = new ArrayList<String>(listFiles.length);
        int idx = dirFile.getAbsolutePath().length();

        for (File f : listFiles) {
            String fname = f.getAbsolutePath().substring(idx);

            if (fname.charAt(0) == '/') {
                fname = fname.substring(1);
            }

            if (f.isDirectory()) {
                fname = fname.concat("/"); // NOI18N
            }

            result.add(fname);
        }

        return result;
    }
}

==> netbeans_8.1+dfsg2.orig.tar.xz: netbeans-8.1/dlight.nativeexecution/src/org/netbeans/modules/nativeexecution/support/ui/SSHKeyFileCompletionProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */
package org.netbeans.modules.nativeexecution.support.ui;

import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironmentFactory;
import org.netbeans.modules.nativeexecution.support.ui.api.FileNamesCompletionProvider;
import org.openide.util.Utilities;

/**
 * Doesn't work on Windows
 * 
 * @author akrasny
 */
public final class SSHKeyFileCompletionProvider extends FileNamesCompletionProvider {

    final boolean isWindows = Utilities.isWindows();

    public SSHKeyFileCompletionProvider() {
        super(ExecutionEnvironmentFactory.getLocal());
    }

    @Override
    protected List<String> listDir(String dir) {
        if (isWindows) {
            return Collections.emptyList();
        }

        File dirFile = new File(dir);

        if (!dirFile.exists() || !dirFile.isDirectory()) {
            return Collections.emptyList();
        }

        final File[] listFiles = dirFile.listFiles(SSHKeyFileFilter.getInstance());

        if (listFiles == null) {
            return Collections.emptyList();
        }

        List<String> result = new ArrayList<>(listFiles.length);
        int idx = dirFile.getAbsolutePath().length();

        for (File f : listFiles) {
            String fname = f.getAbsolutePath().substring(idx);

            if (fname.charAt(0) == '/') {
                fname = fname.substring(1);
            }

            if (f.isDirectory()) {
                fname = fname.concat("/"); // NOI18N
            }

            result.add(fname);
        }

        return result;
    }
}
